# -*- coding: UTF-8 -*-
###########################################################################
# Eole NG - 2007
# Copyright Pole de Competence Eole  (Ministere Education - Academie Dijon)
# Licence CeCill  cf /root/LicenceEole.txt
# eole@ac-dijon.fr
###########################################################################
"""
Fichier de configuration de l'application Zephir
"""
from os.path import join, dirname, abspath
from creole.parsedico import parse_dico
import locale
from twisted.python import log
log.FileLogObserver.timeFormat = "%Y/%m/%d %H:%M:%S %Z"

conf = parse_dico()

charset = "UTF-8"

ADRESSE_LDAP = conf["serveur_ldap"]
ADRESSE_ZEPHIR = conf["adresse_ip_eth0"]
BASE_LDAP = conf["base_ldap"]
PORT_HTTP = "8090"
PORT_ZEPHIR = "7080"
PORT_WEB = 8070
NO_LOCAL_AGENTS = conf.get("no_local_agents", "non")

LOG_ACTIONS = False
if conf.get('log_actions', 'non') == 'oui':
    # Logguer les appels xmlrpc authentifiés dans les logs du backend
    LOG_ACTIONS = True

# répertoire de base appli
ROOT_DIR = "/usr/share/zephir/"
PORT_AGENT = "8090"
AGENT_DIR = "agents"
CLIENT_UPDATE_HOST = "eoleng.ac-dijon.fr"
CLIENT_NG_URL = "/eoleng/eole-%s-security/%s"
SERVEURS_MAJ_CLIENTS = conf['serveur_maj_clients']

MAIL_ADRESSE = conf["serveur_smtp"]
MAIL_PORT = conf["port_smtp"]
MAIL_ACCOUNT = conf["compte_smtp"]

# répertoire de base des donnees backend
PATH_ZEPHIR = "/var/lib/zephir/"
PATH_TEMP = join("/tmp", "zephir_temp")
ADRESSE_SAUVEGARDE = join(PATH_ZEPHIR, 'user_prefs')

# manager prelude par défaut
PRELUDE_PORT = 4691
# liste des modules eole, classés par version
liste_modules = {1:('amon-1.5','sphynx-1.1','scribe-1.0','horus-1.0'),
 2:('amon-2.0','sphynx-2.0','scribe-2.0','horus-2.0','zephir-2.0','preludemanager-2.0','zephirlogs-2.0','sentinelle-2.0'),
 3:('amon-2.1','sphynx-2.1','scribe-2.1','horus-2.1','zephir-2.1','preludemanager-2.1','zephirlogs-2.1','sentinelle-2.1','eclair-2.1'),
 4:('amon-2.2','sphynx-2.2','scribe-2.2','horus-2.2','zephir-2.2','preludemanager-2.2','zephirlogs-2.2','sentinelle-2.2','eclair-2.2','amonecole-2.2','seshat-2.2', 'eolebase-2.2'),
}

# liste des modules autorisés à migrer de plus d'une version
allowed_upgrades = {'horus':{2:[4]},
                    'scribe':{2:[4]},
                    'amon':{2:[4]}
                   }
# liste des modules autorisés à être modifiés (édition de serveur)
allowed_mod_edits = {4:{'amon':['amonecole'],
                        'amonecole':['amon']}
                    }

# détails des distributions gérées (nom_de_code, version_eole, maintenue)
DISTRIBS = {1:("Mdk 9.X", "1.X", False),
            2:("feisty", "2.0", False),
            3:("gutsy", "2.1", False),
            4:("hardy", "2.2", True)}

# liste des verrous existants et de leurs dépendances
verrous = {'uucp':['Execution des tâches Zephir'],
           'sauvegarde':['Maj-Auto','Maj-Cd'],
           'maj':[],
           'configure':[],
           'reconfigure':[]}

# types  de fichiers à sauvegarder/envoyer
data_files = {0:('Tout', ['dicos','patchs','fichiers_perso','fichiers_zephir','zephir.eol','dico.eol','auth_keys','droits_zephir', 'droits_variante']),
              1:('Dictionnaires/templates/patchs/configuration/clés ssh', ['dicos','patchs','fichiers_perso','zephir.eol','auth_keys']),
              2:('Dictionnaires/templates/patchs', ['dicos','patchs','fichiers_perso']),
              3:('Fichiers divers/paquets', ['fichiers_zephir', 'droits_zephir', 'droits_variante']),
              4:('Configuration seulement (config.eol)', ['zephir.eol']),
              5:('Clés ssh seulement', ['auth_keys']),
             }

# libellés à affecter aux différents types de restrictions de ressources, table et champs correspondant (pour validation)
type_res_label =  {'rne':('numéro RNE', 'etablissements', 'rne'),
                   'groupe':('numéro de groupe', 'groupes_serveurs', 'id'),
                   'id_s':('numéro de serveur', 'serveurs', 'id'),
                   'id_var':('numéro de variante', 'variantes', 'id'),
                   'id_mod':('numéro de module', 'modules', 'id'),
                  }

# correspondance des caractères pour les xml des agents eole1
xml_table={'\\xc9':'\\xc3\\xa9',
           '\\xe9':'\\xc3\\xa9',
           '\\xc8':'\\xc3\\xa8',
           '\\xe8':'\\xc3\\xa8',
           '\\xf4':'\\xc3\\xb4',
           '\\xe0':'\\xc3\\xa0',
           }

# temps entre chaque vérification des timeout (secondes)
SCAN_DELAY = 300
